# Security Policy

## Reporting
As a security company, ONEKEY commits to all of its open source products having sound and secure implementations.

All security bugs in ONEKEY products should be reported by email to security@onekey.com. We strongly suggest that you encrypt your email content using our PGP public key (see below). Security bugs must not  be reported through public Github issues.

In accordance with the [Responsible Full Disclosure Policy (RFPolicy) v2.0](https://dl.packetstormsecurity.net/papers/general/rfpolicy-2.0.txt), your email will be acknowledged within five days. The security team will then keep you informed of the progress being made towards a fix and full announcement at least every five days.

## Disclosure policy
ONEKEY has a 5 step disclosure process.

1. The security report is received and is assigned a primary handler. This person will coordinate the fix and release process.

1. The problem is confirmed and a list of all affected versions is determined.

1. Code is audited to find any potential similar problems.

1. Fixes are prepared and applied to the latest version. These fixes are not committed to the public repository but rather held locally pending the announcement.

1. On the embargo date, the advisory is pushed to the affected repository’s wiki, the changes are pushed to the public repository and new builds are deployed to package repositories. A copy of the advisory is then published in the release notes.

This process can take some time, especially when coordination is required with maintainers of other projects. Every effort will be made to handle the bug in an as timely a manner as possible, however it’s important that we follow the release process above to ensure that the disclosure is handled in a consistent manner.

We will never push silent fixes of reported security issues to our code bases. Our security fixes commit will always contain explicit commit messages describing the issue and fix in details and reference a CVE if applicable. Our security advisories will always credit the reporter either by name, handle, or email address. If the reporter wishes to stay anonymous, we will credit them as “anonymous researcher”.

## PGP Key

```
-----BEGIN PGP PUBLIC KEY BLOCK-----


Gh7fzoVy9KKksJH0j1eFpBa+FgJM8g==
=obzE
-----END PGP PUBLIC KEY BLOCK-----
```
